4Suite API Documentation: Ft.Xml.ThirdParty.Xvif.iframe

4Suite™ API Documentation

# ► Module Ft.Xml.ThirdParty.Xvif.iframe

Classes: Apply, Pipe, Transform, Validate |  |  |  | Globals: IMPORT_PREFIX, RngAbstractException, RngSchemaInvalidException, RngSchemaInvalidRecursionException, StringTypes, XMLNS_NAMESPACE, ascii_letters, ascii_lowercase, ascii_uppercase, digits, hexdigits, letters, lowercase, methods, octdigits, printable, punctuation, undefined, uppercase, whitespace

## Classes

class Apply(Ft.Xml.ThirdParty.Xvif.rng._Container, Ft.Xml.ThirdParty.Xvif.rng._Callback)

  ### Methods

  __init__(self)
    Overrides: __init__ from class _Container
  endElementNS(self, schema, name, qname)
    Overrides: endElementNS from class _Container
  startElementNS(self, schema, name, qname, attrs)
    Overrides: startElementNS from class _Callback

  ### Methods inherited from class Ft.Xml.ThirdParty.Xvif.rng._Container

  append, checkAttributeContent, checkRecursion, deriv, expand, nullable, qualifyRefs, simplify, subPatterns

  ### Methods inherited from class Ft.Xml.ThirdParty.Xvif.rng._Pattern

  __cmp__, __str__, isSimple, path, selfValidate, setParent, set_ns

  ### Methods inherited from class Ft.Xml.ThirdParty.Xvif.rng._Callback

  characters, defaultNs, isOpen, setGrammar, set_datatypeLibrary
class Pipe(Ft.Xml.ThirdParty.Xvif.rng._Pattern, Ft.Xml.ThirdParty.Xvif.rng._Callback)

  ### Methods

  __init__(self)
    Overrides: __init__ from class _Pattern
  append(self, child)
    Overrides: append from class _Pattern
  deriv(self, node)
    Overrides: deriv from class _Pattern
  startElementNS(self, schema, name, qname, attrs)
    Overrides: startElementNS from class _Callback

  ### Methods inherited from class Ft.Xml.ThirdParty.Xvif.rng._Pattern

  __cmp__, __str__, checkAttributeContent, checkRecursion, expand, isSimple, nullable, path, qualifyRefs, selfValidate, setParent, set_ns, simplify, subPatterns

  ### Methods inherited from class Ft.Xml.ThirdParty.Xvif.rng._Callback

  characters, defaultNs, endElementNS, isOpen, setGrammar, set_datatypeLibrary
class Transform(Ft.Xml.ThirdParty.Xvif.rng._Pattern, Ft.Xml.ThirdParty.Xvif.rng._Callback)

  ### Methods

  __init__(self)
    Overrides: __init__ from class _Pattern
  append(self, child)
    Overrides: append from class _Pattern
  set_apply(self, context, value)
  set_type(self, context, value)
  startElementNS(self, schema, name, qname, attrs)
    Overrides: startElementNS from class _Callback
  transform(self, node)

  ### Methods inherited from class Ft.Xml.ThirdParty.Xvif.rng._Pattern

  __cmp__, __str__, checkAttributeContent, checkRecursion, deriv, expand, isSimple, nullable, path, qualifyRefs, selfValidate, setParent, set_ns, simplify, subPatterns

  ### Methods inherited from class Ft.Xml.ThirdParty.Xvif.rng._Callback

  characters, defaultNs, endElementNS, isOpen, setGrammar, set_datatypeLibrary
class Validate(Transform)

  ### Methods

  set_type(self, context, value)
    Overrides: set_type from class Transform
  transform(self, node)
    Overrides: transform from class Transform

  ### Methods inherited from class Transform

  __init__, append, set_apply, startElementNS

  ### Methods inherited from class Ft.Xml.ThirdParty.Xvif.rng._Pattern

  __cmp__, __str__, checkAttributeContent, checkRecursion, deriv, expand, isSimple, nullable, path, qualifyRefs, selfValidate, setParent, set_ns, simplify, subPatterns

  ### Methods inherited from class Ft.Xml.ThirdParty.Xvif.rng._Callback

  characters, defaultNs, endElementNS, isOpen, setGrammar, set_datatypeLibrary

## Globals

IMPORT_PREFIX = 'Ft.Xml.ThirdParty.Xvif.'
RngAbstractException = 'RngAbstractException'
RngSchemaInvalidException = 'RngSchemaInvalidException'
RngSchemaInvalidRecursionException = 'RngSchemaInvalidRecursionException'
StringTypes = (<type 'str'>, <type 'unicode'>)
XMLNS_NAMESPACE = 'http://www.w3.org/2000/xmlns/'
ascii_letters = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'
ascii_lowercase = 'abcdefghijklmnopqrstuvwxyz'
ascii_uppercase = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'
digits = '0123456789'
hexdigits = '0123456789abcdefABCDEF'
letters = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz'
lowercase = 'abcdefghijklmnopqrstuvwxyz'
methods = {'http://namespaces.xmlschemata.org/xvif/datatypes': 'iFrameTypes', 'http://relaxng.org/ns/structure/1.0': 'iFrameRNG', 'http://simonstl.com/ns/fragments/': 'iFrameRegFrag', 'http://www.w3.org/1999/XSL/Transform': 'iFrameXSLT'}
octdigits = '01234567'
printable = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ!"#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~ \t\n\r\x0b\x0c'
punctuation = '!"#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~'
undefined = '::undefined::'
uppercase = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'
whitespace = '\t\n\x0b\x0c\r '